# Data

Data management strategies
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**pin** | **bool** | Pin the dataset or not. Refer to &lt;a href&#x3D;\&quot;https://docs.alluxio.io/os/user/stable/en/operation/User-CLI.html#pin\&quot;&gt;Alluxio User-CLI pin&lt;/a&gt; | [optional] [default to False]
**replicas** | **int** | The copies of the dataset | [optional] [default to 0]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


